@@ -5,20 +5,27 @@ require Exporter;
 our @ISA       = qw(Exporter);
 our @EXPORT_OK = qw(explain_child_error);
 
-our $VERSION = '0.27'; # VERSION
+our $VERSION = '0.28'; # VERSION
 
 sub explain_child_error {
-    my $e = shift // $?;
+    my ($num, $str);
+    if (defined $_[0]) {
+        $num = $_[0];
+        $str = $_[1];
+    } else {
+        $num = $?;
+        $str = $!;
+    }
 
-    if ($e == -1) {
-        return "failed to execute: $e";
-    } elsif ($e & 127) {
+    if ($num == -1) {
+        return "failed to execute: ".($str ? "$str ":"")."($num)";
+    } elsif ($num & 127) {
         return sprintf(
             "died with signal %d, %s coredump",
-            ($e & 127),
-            (($e & 128) ? 'with' : 'without'));
+            ($num & 127),
+            (($num & 128) ? 'with' : 'without'));
     } else {
-        return sprintf("exited with value %d", $e >> 8);
+        return sprintf("exited with code %d", $num >> 8);
     }
 }
 
@@ -35,16 +42,18 @@ SHARYANTO::Proc::ChildError - Explain process child error
 
 =head1 VERSION
 
-version 0.27
+version 0.28
 
 =head1 FUNCTIONS
 
-=head2 explain_child_error(INT) => STR
+=head2 explain_child_error($child_error, $os_error) => STR
 
-Taken from perldoc -f system. Converts error number to something like one of the
-following:
+Produce a string description of an error number. C<$child_error> defaults to
+C<$?> if not specified. C<$os_error> defaults to C<$!> if not specified.
 
- failed to execute: -1
+The algorithm is taken from perldoc -f system. Some sample output:
+
+ failed to execute: No such file or directory (-1)
  died with signal 15, with coredump
  exited with value 3
 
